# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .awr_query_result import AwrQueryResult
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrDbCpuUsageCollection(AwrQueryResult):
    """
    The AWR CPU usage data.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrDbCpuUsageCollection object with values from keyword arguments. The default value of the :py:attr:`~oci.database_management.models.AwrDbCpuUsageCollection.awr_result_type` attribute
        of this class is ``AWRDB_ASH_CPU_USAGE_SET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AwrDbCpuUsageCollection.
        :type name: str

        :param version:
            The value to assign to the version property of this AwrDbCpuUsageCollection.
        :type version: str

        :param query_key:
            The value to assign to the query_key property of this AwrDbCpuUsageCollection.
        :type query_key: str

        :param db_query_time_in_secs:
            The value to assign to the db_query_time_in_secs property of this AwrDbCpuUsageCollection.
        :type db_query_time_in_secs: float

        :param awr_result_type:
            The value to assign to the awr_result_type property of this AwrDbCpuUsageCollection.
            Allowed values for this property are: "AWRDB_SET", "AWRDB_SNAPSHOT_RANGE_SET", "AWRDB_SNAPSHOT_SET", "AWRDB_METRICS_SET", "AWRDB_SYSSTAT_SET", "AWRDB_TOP_EVENT_SET", "AWRDB_EVENT_SET", "AWRDB_EVENT_HISTOGRAM", "AWRDB_DB_PARAMETER_SET", "AWRDB_DB_PARAMETER_CHANGE", "AWRDB_ASH_CPU_USAGE_SET", "AWRDB_DB_REPORT", "AWRDB_SQL_REPORT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type awr_result_type: str

        :param num_cpu_cores:
            The value to assign to the num_cpu_cores property of this AwrDbCpuUsageCollection.
        :type num_cpu_cores: int

        :param cpu_count:
            The value to assign to the cpu_count property of this AwrDbCpuUsageCollection.
        :type cpu_count: int

        :param num_cpus:
            The value to assign to the num_cpus property of this AwrDbCpuUsageCollection.
        :type num_cpus: float

        :param items:
            The value to assign to the items property of this AwrDbCpuUsageCollection.
        :type items: list[oci.database_management.models.AwrDbCpuUsageSummary]

        """
        self.swagger_types = {
            'name': 'str',
            'version': 'str',
            'query_key': 'str',
            'db_query_time_in_secs': 'float',
            'awr_result_type': 'str',
            'num_cpu_cores': 'int',
            'cpu_count': 'int',
            'num_cpus': 'float',
            'items': 'list[AwrDbCpuUsageSummary]'
        }

        self.attribute_map = {
            'name': 'name',
            'version': 'version',
            'query_key': 'queryKey',
            'db_query_time_in_secs': 'dbQueryTimeInSecs',
            'awr_result_type': 'awrResultType',
            'num_cpu_cores': 'numCpuCores',
            'cpu_count': 'cpuCount',
            'num_cpus': 'numCpus',
            'items': 'items'
        }

        self._name = None
        self._version = None
        self._query_key = None
        self._db_query_time_in_secs = None
        self._awr_result_type = None
        self._num_cpu_cores = None
        self._cpu_count = None
        self._num_cpus = None
        self._items = None
        self._awr_result_type = 'AWRDB_ASH_CPU_USAGE_SET'

    @property
    def num_cpu_cores(self):
        """
        Gets the num_cpu_cores of this AwrDbCpuUsageCollection.
        The number of available CPU cores, which include subcores of multicore and single-core CPUs.


        :return: The num_cpu_cores of this AwrDbCpuUsageCollection.
        :rtype: int
        """
        return self._num_cpu_cores

    @num_cpu_cores.setter
    def num_cpu_cores(self, num_cpu_cores):
        """
        Sets the num_cpu_cores of this AwrDbCpuUsageCollection.
        The number of available CPU cores, which include subcores of multicore and single-core CPUs.


        :param num_cpu_cores: The num_cpu_cores of this AwrDbCpuUsageCollection.
        :type: int
        """
        self._num_cpu_cores = num_cpu_cores

    @property
    def cpu_count(self):
        """
        Gets the cpu_count of this AwrDbCpuUsageCollection.
        The number of CPUs available for the database to use.


        :return: The cpu_count of this AwrDbCpuUsageCollection.
        :rtype: int
        """
        return self._cpu_count

    @cpu_count.setter
    def cpu_count(self, cpu_count):
        """
        Sets the cpu_count of this AwrDbCpuUsageCollection.
        The number of CPUs available for the database to use.


        :param cpu_count: The cpu_count of this AwrDbCpuUsageCollection.
        :type: int
        """
        self._cpu_count = cpu_count

    @property
    def num_cpus(self):
        """
        Gets the num_cpus of this AwrDbCpuUsageCollection.
        The number of available CPUs or processors.


        :return: The num_cpus of this AwrDbCpuUsageCollection.
        :rtype: float
        """
        return self._num_cpus

    @num_cpus.setter
    def num_cpus(self, num_cpus):
        """
        Sets the num_cpus of this AwrDbCpuUsageCollection.
        The number of available CPUs or processors.


        :param num_cpus: The num_cpus of this AwrDbCpuUsageCollection.
        :type: float
        """
        self._num_cpus = num_cpus

    @property
    def items(self):
        """
        Gets the items of this AwrDbCpuUsageCollection.
        A list of AWR CPU usage summary data.


        :return: The items of this AwrDbCpuUsageCollection.
        :rtype: list[oci.database_management.models.AwrDbCpuUsageSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this AwrDbCpuUsageCollection.
        A list of AWR CPU usage summary data.


        :param items: The items of this AwrDbCpuUsageCollection.
        :type: list[oci.database_management.models.AwrDbCpuUsageSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .add_exadata_insight_members_details import AddExadataInsightMembersDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddEmManagedExternalExadataInsightMembersDetails(AddExadataInsightMembersDetails):
    """
    The information about the members of Exadata system to be added. If memberEntityDetails is not specified, the the Enterprise Manager entity (e.g. databases and hosts) associated with an Exadata system will be placed in the same compartment as the Exadata system.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AddEmManagedExternalExadataInsightMembersDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.AddEmManagedExternalExadataInsightMembersDetails.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_EXADATA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this AddEmManagedExternalExadataInsightMembersDetails.
            Allowed values for this property are: "EM_MANAGED_EXTERNAL_EXADATA"
        :type entity_source: str

        :param member_entity_details:
            The value to assign to the member_entity_details property of this AddEmManagedExternalExadataInsightMembersDetails.
        :type member_entity_details: list[oci.opsi.models.CreateEmManagedExternalExadataMemberEntityDetails]

        """
        self.swagger_types = {
            'entity_source': 'str',
            'member_entity_details': 'list[CreateEmManagedExternalExadataMemberEntityDetails]'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'member_entity_details': 'memberEntityDetails'
        }

        self._entity_source = None
        self._member_entity_details = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_EXADATA'

    @property
    def member_entity_details(self):
        """
        Gets the member_entity_details of this AddEmManagedExternalExadataInsightMembersDetails.

        :return: The member_entity_details of this AddEmManagedExternalExadataInsightMembersDetails.
        :rtype: list[oci.opsi.models.CreateEmManagedExternalExadataMemberEntityDetails]
        """
        return self._member_entity_details

    @member_entity_details.setter
    def member_entity_details(self, member_entity_details):
        """
        Sets the member_entity_details of this AddEmManagedExternalExadataInsightMembersDetails.

        :param member_entity_details: The member_entity_details of this AddEmManagedExternalExadataInsightMembersDetails.
        :type: list[oci.opsi.models.CreateEmManagedExternalExadataMemberEntityDetails]
        """
        self._member_entity_details = member_entity_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Database(object):
    """
    Database model.
    """

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "BACKUP_IN_PROGRESS"
    LIFECYCLE_STATE_BACKUP_IN_PROGRESS = "BACKUP_IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "UPGRADING"
    LIFECYCLE_STATE_UPGRADING = "UPGRADING"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "CONVERTING"
    LIFECYCLE_STATE_CONVERTING = "CONVERTING"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "RESTORE_FAILED"
    LIFECYCLE_STATE_RESTORE_FAILED = "RESTORE_FAILED"

    #: A constant which can be used with the lifecycle_state property of a Database.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Database object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Database.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Database.
        :type compartment_id: str

        :param character_set:
            The value to assign to the character_set property of this Database.
        :type character_set: str

        :param ncharacter_set:
            The value to assign to the ncharacter_set property of this Database.
        :type ncharacter_set: str

        :param db_home_id:
            The value to assign to the db_home_id property of this Database.
        :type db_home_id: str

        :param db_system_id:
            The value to assign to the db_system_id property of this Database.
        :type db_system_id: str

        :param vm_cluster_id:
            The value to assign to the vm_cluster_id property of this Database.
        :type vm_cluster_id: str

        :param db_name:
            The value to assign to the db_name property of this Database.
        :type db_name: str

        :param pdb_name:
            The value to assign to the pdb_name property of this Database.
        :type pdb_name: str

        :param db_workload:
            The value to assign to the db_workload property of this Database.
        :type db_workload: str

        :param db_unique_name:
            The value to assign to the db_unique_name property of this Database.
        :type db_unique_name: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Database.
        :type lifecycle_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Database.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "BACKUP_IN_PROGRESS", "UPGRADING", "CONVERTING", "TERMINATING", "TERMINATED", "RESTORE_FAILED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this Database.
        :type time_created: datetime

        :param last_backup_timestamp:
            The value to assign to the last_backup_timestamp property of this Database.
        :type last_backup_timestamp: datetime

        :param db_backup_config:
            The value to assign to the db_backup_config property of this Database.
        :type db_backup_config: oci.database.models.DbBackupConfig

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Database.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Database.
        :type defined_tags: dict(str, dict(str, object))

        :param connection_strings:
            The value to assign to the connection_strings property of this Database.
        :type connection_strings: oci.database.models.DatabaseConnectionStrings

        :param kms_key_id:
            The value to assign to the kms_key_id property of this Database.
        :type kms_key_id: str

        :param kms_key_version_id:
            The value to assign to the kms_key_version_id property of this Database.
        :type kms_key_version_id: str

        :param vault_id:
            The value to assign to the vault_id property of this Database.
        :type vault_id: str

        :param source_database_point_in_time_recovery_timestamp:
            The value to assign to the source_database_point_in_time_recovery_timestamp property of this Database.
        :type source_database_point_in_time_recovery_timestamp: datetime

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this Database.
        :type database_software_image_id: str

        :param is_cdb:
            The value to assign to the is_cdb property of this Database.
        :type is_cdb: bool

        :param database_management_config:
            The value to assign to the database_management_config property of this Database.
        :type database_management_config: oci.database.models.CloudDatabaseManagementConfig

        :param sid_prefix:
            The value to assign to the sid_prefix property of this Database.
        :type sid_prefix: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'character_set': 'str',
            'ncharacter_set': 'str',
            'db_home_id': 'str',
            'db_system_id': 'str',
            'vm_cluster_id': 'str',
            'db_name': 'str',
            'pdb_name': 'str',
            'db_workload': 'str',
            'db_unique_name': 'str',
            'lifecycle_details': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'last_backup_timestamp': 'datetime',
            'db_backup_config': 'DbBackupConfig',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'connection_strings': 'DatabaseConnectionStrings',
            'kms_key_id': 'str',
            'kms_key_version_id': 'str',
            'vault_id': 'str',
            'source_database_point_in_time_recovery_timestamp': 'datetime',
            'database_software_image_id': 'str',
            'is_cdb': 'bool',
            'database_management_config': 'CloudDatabaseManagementConfig',
            'sid_prefix': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'character_set': 'characterSet',
            'ncharacter_set': 'ncharacterSet',
            'db_home_id': 'dbHomeId',
            'db_system_id': 'dbSystemId',
            'vm_cluster_id': 'vmClusterId',
            'db_name': 'dbName',
            'pdb_name': 'pdbName',
            'db_workload': 'dbWorkload',
            'db_unique_name': 'dbUniqueName',
            'lifecycle_details': 'lifecycleDetails',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'last_backup_timestamp': 'lastBackupTimestamp',
            'db_backup_config': 'dbBackupConfig',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'connection_strings': 'connectionStrings',
            'kms_key_id': 'kmsKeyId',
            'kms_key_version_id': 'kmsKeyVersionId',
            'vault_id': 'vaultId',
            'source_database_point_in_time_recovery_timestamp': 'sourceDatabasePointInTimeRecoveryTimestamp',
            'database_software_image_id': 'databaseSoftwareImageId',
            'is_cdb': 'isCdb',
            'database_management_config': 'databaseManagementConfig',
            'sid_prefix': 'sidPrefix'
        }

        self._id = None
        self._compartment_id = None
        self._character_set = None
        self._ncharacter_set = None
        self._db_home_id = None
        self._db_system_id = None
        self._vm_cluster_id = None
        self._db_name = None
        self._pdb_name = None
        self._db_workload = None
        self._db_unique_name = None
        self._lifecycle_details = None
        self._lifecycle_state = None
        self._time_created = None
        self._last_backup_timestamp = None
        self._db_backup_config = None
        self._freeform_tags = None
        self._defined_tags = None
        self._connection_strings = None
        self._kms_key_id = None
        self._kms_key_version_id = None
        self._vault_id = None
        self._source_database_point_in_time_recovery_timestamp = None
        self._database_software_image_id = None
        self._is_cdb = None
        self._database_management_config = None
        self._sid_prefix = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Database.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this Database.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Database.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this Database.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Database.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Database.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Database.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Database.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def character_set(self):
        """
        Gets the character_set of this Database.
        The character set for the database.


        :return: The character_set of this Database.
        :rtype: str
        """
        return self._character_set

    @character_set.setter
    def character_set(self, character_set):
        """
        Sets the character_set of this Database.
        The character set for the database.


        :param character_set: The character_set of this Database.
        :type: str
        """
        self._character_set = character_set

    @property
    def ncharacter_set(self):
        """
        Gets the ncharacter_set of this Database.
        The national character set for the database.


        :return: The ncharacter_set of this Database.
        :rtype: str
        """
        return self._ncharacter_set

    @ncharacter_set.setter
    def ncharacter_set(self, ncharacter_set):
        """
        Sets the ncharacter_set of this Database.
        The national character set for the database.


        :param ncharacter_set: The ncharacter_set of this Database.
        :type: str
        """
        self._ncharacter_set = ncharacter_set

    @property
    def db_home_id(self):
        """
        Gets the db_home_id of this Database.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The db_home_id of this Database.
        :rtype: str
        """
        return self._db_home_id

    @db_home_id.setter
    def db_home_id(self, db_home_id):
        """
        Sets the db_home_id of this Database.
        The `OCID`__ of the Database Home.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param db_home_id: The db_home_id of this Database.
        :type: str
        """
        self._db_home_id = db_home_id

    @property
    def db_system_id(self):
        """
        Gets the db_system_id of this Database.
        The `OCID`__ of the DB system.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The db_system_id of this Database.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this Database.
        The `OCID`__ of the DB system.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param db_system_id: The db_system_id of this Database.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def vm_cluster_id(self):
        """
        Gets the vm_cluster_id of this Database.
        The `OCID`__ of the VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vm_cluster_id of this Database.
        :rtype: str
        """
        return self._vm_cluster_id

    @vm_cluster_id.setter
    def vm_cluster_id(self, vm_cluster_id):
        """
        Sets the vm_cluster_id of this Database.
        The `OCID`__ of the VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vm_cluster_id: The vm_cluster_id of this Database.
        :type: str
        """
        self._vm_cluster_id = vm_cluster_id

    @property
    def db_name(self):
        """
        **[Required]** Gets the db_name of this Database.
        The database name.


        :return: The db_name of this Database.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """
        Sets the db_name of this Database.
        The database name.


        :param db_name: The db_name of this Database.
        :type: str
        """
        self._db_name = db_name

    @property
    def pdb_name(self):
        """
        Gets the pdb_name of this Database.
        The name of the pluggable database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. Pluggable database should not be same as database name.


        :return: The pdb_name of this Database.
        :rtype: str
        """
        return self._pdb_name

    @pdb_name.setter
    def pdb_name(self, pdb_name):
        """
        Sets the pdb_name of this Database.
        The name of the pluggable database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. Pluggable database should not be same as database name.


        :param pdb_name: The pdb_name of this Database.
        :type: str
        """
        self._pdb_name = pdb_name

    @property
    def db_workload(self):
        """
        Gets the db_workload of this Database.
        The database workload type.


        :return: The db_workload of this Database.
        :rtype: str
        """
        return self._db_workload

    @db_workload.setter
    def db_workload(self, db_workload):
        """
        Sets the db_workload of this Database.
        The database workload type.


        :param db_workload: The db_workload of this Database.
        :type: str
        """
        self._db_workload = db_workload

    @property
    def db_unique_name(self):
        """
        **[Required]** Gets the db_unique_name of this Database.
        A system-generated name for the database to ensure uniqueness within an Oracle Data Guard group (a primary database and its standby databases). The unique name cannot be changed.


        :return: The db_unique_name of this Database.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this Database.
        A system-generated name for the database to ensure uniqueness within an Oracle Data Guard group (a primary database and its standby databases). The unique name cannot be changed.


        :param db_unique_name: The db_unique_name of this Database.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Database.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this Database.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Database.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this Database.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Database.
        The current state of the database.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "BACKUP_IN_PROGRESS", "UPGRADING", "CONVERTING", "TERMINATING", "TERMINATED", "RESTORE_FAILED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Database.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Database.
        The current state of the database.


        :param lifecycle_state: The lifecycle_state of this Database.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "UPDATING", "BACKUP_IN_PROGRESS", "UPGRADING", "CONVERTING", "TERMINATING", "TERMINATED", "RESTORE_FAILED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this Database.
        The date and time the database was created.


        :return: The time_created of this Database.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Database.
        The date and time the database was created.


        :param time_created: The time_created of this Database.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def last_backup_timestamp(self):
        """
        Gets the last_backup_timestamp of this Database.
        The date and time when the latest database backup was created.


        :return: The last_backup_timestamp of this Database.
        :rtype: datetime
        """
        return self._last_backup_timestamp

    @last_backup_timestamp.setter
    def last_backup_timestamp(self, last_backup_timestamp):
        """
        Sets the last_backup_timestamp of this Database.
        The date and time when the latest database backup was created.


        :param last_backup_timestamp: The last_backup_timestamp of this Database.
        :type: datetime
        """
        self._last_backup_timestamp = last_backup_timestamp

    @property
    def db_backup_config(self):
        """
        Gets the db_backup_config of this Database.

        :return: The db_backup_config of this Database.
        :rtype: oci.database.models.DbBackupConfig
        """
        return self._db_backup_config

    @db_backup_config.setter
    def db_backup_config(self, db_backup_config):
        """
        Sets the db_backup_config of this Database.

        :param db_backup_config: The db_backup_config of this Database.
        :type: oci.database.models.DbBackupConfig
        """
        self._db_backup_config = db_backup_config

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Database.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Database.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Database.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Database.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Database.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Database.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Database.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Database.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def connection_strings(self):
        """
        Gets the connection_strings of this Database.
        The Connection strings used to connect to the Oracle Database.


        :return: The connection_strings of this Database.
        :rtype: oci.database.models.DatabaseConnectionStrings
        """
        return self._connection_strings

    @connection_strings.setter
    def connection_strings(self, connection_strings):
        """
        Sets the connection_strings of this Database.
        The Connection strings used to connect to the Oracle Database.


        :param connection_strings: The connection_strings of this Database.
        :type: oci.database.models.DatabaseConnectionStrings
        """
        self._connection_strings = connection_strings

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this Database.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :return: The kms_key_id of this Database.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this Database.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :param kms_key_id: The kms_key_id of this Database.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def kms_key_version_id(self):
        """
        Gets the kms_key_version_id of this Database.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :return: The kms_key_version_id of this Database.
        :rtype: str
        """
        return self._kms_key_version_id

    @kms_key_version_id.setter
    def kms_key_version_id(self, kms_key_version_id):
        """
        Sets the kms_key_version_id of this Database.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :param kms_key_version_id: The kms_key_version_id of this Database.
        :type: str
        """
        self._kms_key_version_id = kms_key_version_id

    @property
    def vault_id(self):
        """
        Gets the vault_id of this Database.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :return: The vault_id of this Database.
        :rtype: str
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """
        Sets the vault_id of this Database.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :param vault_id: The vault_id of this Database.
        :type: str
        """
        self._vault_id = vault_id

    @property
    def source_database_point_in_time_recovery_timestamp(self):
        """
        Gets the source_database_point_in_time_recovery_timestamp of this Database.
        Point in time recovery timeStamp of the source database at which cloned database system is cloned from the source database system, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The source_database_point_in_time_recovery_timestamp of this Database.
        :rtype: datetime
        """
        return self._source_database_point_in_time_recovery_timestamp

    @source_database_point_in_time_recovery_timestamp.setter
    def source_database_point_in_time_recovery_timestamp(self, source_database_point_in_time_recovery_timestamp):
        """
        Sets the source_database_point_in_time_recovery_timestamp of this Database.
        Point in time recovery timeStamp of the source database at which cloned database system is cloned from the source database system, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param source_database_point_in_time_recovery_timestamp: The source_database_point_in_time_recovery_timestamp of this Database.
        :type: datetime
        """
        self._source_database_point_in_time_recovery_timestamp = source_database_point_in_time_recovery_timestamp

    @property
    def database_software_image_id(self):
        """
        Gets the database_software_image_id of this Database.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_software_image_id of this Database.
        :rtype: str
        """
        return self._database_software_image_id

    @database_software_image_id.setter
    def database_software_image_id(self, database_software_image_id):
        """
        Sets the database_software_image_id of this Database.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_software_image_id: The database_software_image_id of this Database.
        :type: str
        """
        self._database_software_image_id = database_software_image_id

    @property
    def is_cdb(self):
        """
        Gets the is_cdb of this Database.
        True if the database is a container database.


        :return: The is_cdb of this Database.
        :rtype: bool
        """
        return self._is_cdb

    @is_cdb.setter
    def is_cdb(self, is_cdb):
        """
        Sets the is_cdb of this Database.
        True if the database is a container database.


        :param is_cdb: The is_cdb of this Database.
        :type: bool
        """
        self._is_cdb = is_cdb

    @property
    def database_management_config(self):
        """
        Gets the database_management_config of this Database.

        :return: The database_management_config of this Database.
        :rtype: oci.database.models.CloudDatabaseManagementConfig
        """
        return self._database_management_config

    @database_management_config.setter
    def database_management_config(self, database_management_config):
        """
        Sets the database_management_config of this Database.

        :param database_management_config: The database_management_config of this Database.
        :type: oci.database.models.CloudDatabaseManagementConfig
        """
        self._database_management_config = database_management_config

    @property
    def sid_prefix(self):
        """
        Gets the sid_prefix of this Database.
        Specifies a prefix for the `Oracle SID` of the database to be created.


        :return: The sid_prefix of this Database.
        :rtype: str
        """
        return self._sid_prefix

    @sid_prefix.setter
    def sid_prefix(self, sid_prefix):
        """
        Sets the sid_prefix of this Database.
        Specifies a prefix for the `Oracle SID` of the database to be created.


        :param sid_prefix: The sid_prefix of this Database.
        :type: str
        """
        self._sid_prefix = sid_prefix

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DevopsCodeRepositoryFilterAttributes(object):
    """
    Attributes to filter DevOps code repository events.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DevopsCodeRepositoryFilterAttributes object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param head_ref:
            The value to assign to the head_ref property of this DevopsCodeRepositoryFilterAttributes.
        :type head_ref: str

        """
        self.swagger_types = {
            'head_ref': 'str'
        }

        self.attribute_map = {
            'head_ref': 'headRef'
        }

        self._head_ref = None

    @property
    def head_ref(self):
        """
        Gets the head_ref of this DevopsCodeRepositoryFilterAttributes.
        Branch for push event.


        :return: The head_ref of this DevopsCodeRepositoryFilterAttributes.
        :rtype: str
        """
        return self._head_ref

    @head_ref.setter
    def head_ref(self, head_ref):
        """
        Sets the head_ref of this DevopsCodeRepositoryFilterAttributes.
        Branch for push event.


        :param head_ref: The head_ref of this DevopsCodeRepositoryFilterAttributes.
        :type: str
        """
        self._head_ref = head_ref

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionSummary(object):
    """
    Summary of subscription.
    """

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SubscriptionSummary.
        :type id: str

        :param classic_subscription_id:
            The value to assign to the classic_subscription_id property of this SubscriptionSummary.
        :type classic_subscription_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this SubscriptionSummary.
        :type compartment_id: str

        :param service_name:
            The value to assign to the service_name property of this SubscriptionSummary.
        :type service_name: str

        :param is_classic_subscription:
            The value to assign to the is_classic_subscription property of this SubscriptionSummary.
        :type is_classic_subscription: bool

        :param payment_model:
            The value to assign to the payment_model property of this SubscriptionSummary.
        :type payment_model: str

        :param region_assignment:
            The value to assign to the region_assignment property of this SubscriptionSummary.
        :type region_assignment: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SubscriptionSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param start_date:
            The value to assign to the start_date property of this SubscriptionSummary.
        :type start_date: datetime

        :param end_date:
            The value to assign to the end_date property of this SubscriptionSummary.
        :type end_date: datetime

        :param time_updated:
            The value to assign to the time_updated property of this SubscriptionSummary.
        :type time_updated: datetime

        :param time_created:
            The value to assign to the time_created property of this SubscriptionSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'classic_subscription_id': 'str',
            'compartment_id': 'str',
            'service_name': 'str',
            'is_classic_subscription': 'bool',
            'payment_model': 'str',
            'region_assignment': 'str',
            'lifecycle_state': 'str',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'time_updated': 'datetime',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'classic_subscription_id': 'classicSubscriptionId',
            'compartment_id': 'compartmentId',
            'service_name': 'serviceName',
            'is_classic_subscription': 'isClassicSubscription',
            'payment_model': 'paymentModel',
            'region_assignment': 'regionAssignment',
            'lifecycle_state': 'lifecycleState',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'time_updated': 'timeUpdated',
            'time_created': 'timeCreated'
        }

        self._id = None
        self._classic_subscription_id = None
        self._compartment_id = None
        self._service_name = None
        self._is_classic_subscription = None
        self._payment_model = None
        self._region_assignment = None
        self._lifecycle_state = None
        self._start_date = None
        self._end_date = None
        self._time_updated = None
        self._time_created = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SubscriptionSummary.
        OCID of the subscription details for a particular root compartment or tenancy.


        :return: The id of this SubscriptionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SubscriptionSummary.
        OCID of the subscription details for a particular root compartment or tenancy.


        :param id: The id of this SubscriptionSummary.
        :type: str
        """
        self._id = id

    @property
    def classic_subscription_id(self):
        """
        **[Required]** Gets the classic_subscription_id of this SubscriptionSummary.
        Classic subscription ID.


        :return: The classic_subscription_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._classic_subscription_id

    @classic_subscription_id.setter
    def classic_subscription_id(self, classic_subscription_id):
        """
        Sets the classic_subscription_id of this SubscriptionSummary.
        Classic subscription ID.


        :param classic_subscription_id: The classic_subscription_id of this SubscriptionSummary.
        :type: str
        """
        self._classic_subscription_id = classic_subscription_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this SubscriptionSummary.
        OCID of the compartment. Always a tenancy OCID.


        :return: The compartment_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SubscriptionSummary.
        OCID of the compartment. Always a tenancy OCID.


        :param compartment_id: The compartment_id of this SubscriptionSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def service_name(self):
        """
        **[Required]** Gets the service_name of this SubscriptionSummary.
        The type of subscription, such as 'CLOUDCM', 'SAAS', 'ERP', or 'CRM'.


        :return: The service_name of this SubscriptionSummary.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this SubscriptionSummary.
        The type of subscription, such as 'CLOUDCM', 'SAAS', 'ERP', or 'CRM'.


        :param service_name: The service_name of this SubscriptionSummary.
        :type: str
        """
        self._service_name = service_name

    @property
    def is_classic_subscription(self):
        """
        Gets the is_classic_subscription of this SubscriptionSummary.
        Denotes if the subscription is from classic systems or not.


        :return: The is_classic_subscription of this SubscriptionSummary.
        :rtype: bool
        """
        return self._is_classic_subscription

    @is_classic_subscription.setter
    def is_classic_subscription(self, is_classic_subscription):
        """
        Sets the is_classic_subscription of this SubscriptionSummary.
        Denotes if the subscription is from classic systems or not.


        :param is_classic_subscription: The is_classic_subscription of this SubscriptionSummary.
        :type: bool
        """
        self._is_classic_subscription = is_classic_subscription

    @property
    def payment_model(self):
        """
        Gets the payment_model of this SubscriptionSummary.
        The pay model of the subscription, such as 'Pay as you go' or 'Monthly'.


        :return: The payment_model of this SubscriptionSummary.
        :rtype: str
        """
        return self._payment_model

    @payment_model.setter
    def payment_model(self, payment_model):
        """
        Sets the payment_model of this SubscriptionSummary.
        The pay model of the subscription, such as 'Pay as you go' or 'Monthly'.


        :param payment_model: The payment_model of this SubscriptionSummary.
        :type: str
        """
        self._payment_model = payment_model

    @property
    def region_assignment(self):
        """
        Gets the region_assignment of this SubscriptionSummary.
        Region for the subscription.


        :return: The region_assignment of this SubscriptionSummary.
        :rtype: str
        """
        return self._region_assignment

    @region_assignment.setter
    def region_assignment(self, region_assignment):
        """
        Sets the region_assignment of this SubscriptionSummary.
        Region for the subscription.


        :param region_assignment: The region_assignment of this SubscriptionSummary.
        :type: str
        """
        self._region_assignment = region_assignment

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this SubscriptionSummary.
        Lifecycle state of the subscription.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SubscriptionSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SubscriptionSummary.
        Lifecycle state of the subscription.


        :param lifecycle_state: The lifecycle_state of this SubscriptionSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def start_date(self):
        """
        Gets the start_date of this SubscriptionSummary.
        Subscription start time.


        :return: The start_date of this SubscriptionSummary.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this SubscriptionSummary.
        Subscription start time.


        :param start_date: The start_date of this SubscriptionSummary.
        :type: datetime
        """
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this SubscriptionSummary.
        Subscription end time.


        :return: The end_date of this SubscriptionSummary.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this SubscriptionSummary.
        Subscription end time.


        :param end_date: The end_date of this SubscriptionSummary.
        :type: datetime
        """
        self._end_date = end_date

    @property
    def time_updated(self):
        """
        Gets the time_updated of this SubscriptionSummary.
        Date-time when subscription is updated.


        :return: The time_updated of this SubscriptionSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this SubscriptionSummary.
        Date-time when subscription is updated.


        :param time_updated: The time_updated of this SubscriptionSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def time_created(self):
        """
        Gets the time_created of this SubscriptionSummary.
        Date-time when subscription is created.


        :return: The time_created of this SubscriptionSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SubscriptionSummary.
        Date-time when subscription is created.


        :param time_created: The time_created of this SubscriptionSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ChangePeComanagedDatabaseInsightDetails(object):
    """
    Details of a Private Endpoint co-managed database insight.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ChangePeComanagedDatabaseInsightDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param service_name:
            The value to assign to the service_name property of this ChangePeComanagedDatabaseInsightDetails.
        :type service_name: str

        :param credential_details:
            The value to assign to the credential_details property of this ChangePeComanagedDatabaseInsightDetails.
        :type credential_details: oci.opsi.models.CredentialDetails

        :param opsi_private_endpoint_id:
            The value to assign to the opsi_private_endpoint_id property of this ChangePeComanagedDatabaseInsightDetails.
        :type opsi_private_endpoint_id: str

        """
        self.swagger_types = {
            'service_name': 'str',
            'credential_details': 'CredentialDetails',
            'opsi_private_endpoint_id': 'str'
        }

        self.attribute_map = {
            'service_name': 'serviceName',
            'credential_details': 'credentialDetails',
            'opsi_private_endpoint_id': 'opsiPrivateEndpointId'
        }

        self._service_name = None
        self._credential_details = None
        self._opsi_private_endpoint_id = None

    @property
    def service_name(self):
        """
        **[Required]** Gets the service_name of this ChangePeComanagedDatabaseInsightDetails.
        Database service name used for connection requests.


        :return: The service_name of this ChangePeComanagedDatabaseInsightDetails.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this ChangePeComanagedDatabaseInsightDetails.
        Database service name used for connection requests.


        :param service_name: The service_name of this ChangePeComanagedDatabaseInsightDetails.
        :type: str
        """
        self._service_name = service_name

    @property
    def credential_details(self):
        """
        **[Required]** Gets the credential_details of this ChangePeComanagedDatabaseInsightDetails.

        :return: The credential_details of this ChangePeComanagedDatabaseInsightDetails.
        :rtype: oci.opsi.models.CredentialDetails
        """
        return self._credential_details

    @credential_details.setter
    def credential_details(self, credential_details):
        """
        Sets the credential_details of this ChangePeComanagedDatabaseInsightDetails.

        :param credential_details: The credential_details of this ChangePeComanagedDatabaseInsightDetails.
        :type: oci.opsi.models.CredentialDetails
        """
        self._credential_details = credential_details

    @property
    def opsi_private_endpoint_id(self):
        """
        **[Required]** Gets the opsi_private_endpoint_id of this ChangePeComanagedDatabaseInsightDetails.
        The `OCID`__ of the OPSI private endpoint

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The opsi_private_endpoint_id of this ChangePeComanagedDatabaseInsightDetails.
        :rtype: str
        """
        return self._opsi_private_endpoint_id

    @opsi_private_endpoint_id.setter
    def opsi_private_endpoint_id(self, opsi_private_endpoint_id):
        """
        Sets the opsi_private_endpoint_id of this ChangePeComanagedDatabaseInsightDetails.
        The `OCID`__ of the OPSI private endpoint

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param opsi_private_endpoint_id: The opsi_private_endpoint_id of this ChangePeComanagedDatabaseInsightDetails.
        :type: str
        """
        self._opsi_private_endpoint_id = opsi_private_endpoint_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_details import DatabaseDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseDetails(DatabaseDetails):
    """
    The details of the Oracle Autonomous Database to be registered as a target database in Data Safe.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.AutonomousDatabaseDetails.database_type` attribute
        of this class is ``AUTONOMOUS_DATABASE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_type:
            The value to assign to the database_type property of this AutonomousDatabaseDetails.
            Allowed values for this property are: "DATABASE_CLOUD_SERVICE", "AUTONOMOUS_DATABASE", "INSTALLED_DATABASE"
        :type database_type: str

        :param infrastructure_type:
            The value to assign to the infrastructure_type property of this AutonomousDatabaseDetails.
            Allowed values for this property are: "ORACLE_CLOUD", "CLOUD_AT_CUSTOMER", "ON_PREMISES", "NON_ORACLE_CLOUD"
        :type infrastructure_type: str

        :param autonomous_database_id:
            The value to assign to the autonomous_database_id property of this AutonomousDatabaseDetails.
        :type autonomous_database_id: str

        """
        self.swagger_types = {
            'database_type': 'str',
            'infrastructure_type': 'str',
            'autonomous_database_id': 'str'
        }

        self.attribute_map = {
            'database_type': 'databaseType',
            'infrastructure_type': 'infrastructureType',
            'autonomous_database_id': 'autonomousDatabaseId'
        }

        self._database_type = None
        self._infrastructure_type = None
        self._autonomous_database_id = None
        self._database_type = 'AUTONOMOUS_DATABASE'

    @property
    def autonomous_database_id(self):
        """
        Gets the autonomous_database_id of this AutonomousDatabaseDetails.
        The OCID of the autonomous database registered as a target database in Data Safe.


        :return: The autonomous_database_id of this AutonomousDatabaseDetails.
        :rtype: str
        """
        return self._autonomous_database_id

    @autonomous_database_id.setter
    def autonomous_database_id(self, autonomous_database_id):
        """
        Sets the autonomous_database_id of this AutonomousDatabaseDetails.
        The OCID of the autonomous database registered as a target database in Data Safe.


        :param autonomous_database_id: The autonomous_database_id of this AutonomousDatabaseDetails.
        :type: str
        """
        self._autonomous_database_id = autonomous_database_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConnectionValidation(object):
    """
    The information about connection validation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConnectionValidation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param validation_message:
            The value to assign to the validation_message property of this ConnectionValidation.
        :type validation_message: oci.data_connectivity.models.Message

        :param key:
            The value to assign to the key property of this ConnectionValidation.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this ConnectionValidation.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this ConnectionValidation.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this ConnectionValidation.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param name:
            The value to assign to the name property of this ConnectionValidation.
        :type name: str

        :param description:
            The value to assign to the description property of this ConnectionValidation.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this ConnectionValidation.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this ConnectionValidation.
        :type object_status: int

        :param registry_metadata:
            The value to assign to the registry_metadata property of this ConnectionValidation.
        :type registry_metadata: oci.data_connectivity.models.RegistryMetadata

        :param connection:
            The value to assign to the connection property of this ConnectionValidation.
        :type connection: oci.data_connectivity.models.CreateConnectionDetails

        :param data_asset:
            The value to assign to the data_asset property of this ConnectionValidation.
        :type data_asset: oci.data_connectivity.models.CreateDataAssetDetails

        :param identifier:
            The value to assign to the identifier property of this ConnectionValidation.
        :type identifier: str

        :param metadata:
            The value to assign to the metadata property of this ConnectionValidation.
        :type metadata: oci.data_connectivity.models.ObjectMetadata

        """
        self.swagger_types = {
            'validation_message': 'Message',
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'registry_metadata': 'RegistryMetadata',
            'connection': 'CreateConnectionDetails',
            'data_asset': 'CreateDataAssetDetails',
            'identifier': 'str',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'validation_message': 'validationMessage',
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'registry_metadata': 'registryMetadata',
            'connection': 'connection',
            'data_asset': 'dataAsset',
            'identifier': 'identifier',
            'metadata': 'metadata'
        }

        self._validation_message = None
        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._registry_metadata = None
        self._connection = None
        self._data_asset = None
        self._identifier = None
        self._metadata = None

    @property
    def validation_message(self):
        """
        Gets the validation_message of this ConnectionValidation.

        :return: The validation_message of this ConnectionValidation.
        :rtype: oci.data_connectivity.models.Message
        """
        return self._validation_message

    @validation_message.setter
    def validation_message(self, validation_message):
        """
        Sets the validation_message of this ConnectionValidation.

        :param validation_message: The validation_message of this ConnectionValidation.
        :type: oci.data_connectivity.models.Message
        """
        self._validation_message = validation_message

    @property
    def key(self):
        """
        Gets the key of this ConnectionValidation.
        Objects will use a 36 character key as unique ID. It is system generated and cannot be modified.


        :return: The key of this ConnectionValidation.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ConnectionValidation.
        Objects will use a 36 character key as unique ID. It is system generated and cannot be modified.


        :param key: The key of this ConnectionValidation.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this ConnectionValidation.
        The type of the object.


        :return: The model_type of this ConnectionValidation.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this ConnectionValidation.
        The type of the object.


        :param model_type: The model_type of this ConnectionValidation.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this ConnectionValidation.
        The model version of an object.


        :return: The model_version of this ConnectionValidation.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this ConnectionValidation.
        The model version of an object.


        :param model_version: The model_version of this ConnectionValidation.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this ConnectionValidation.

        :return: The parent_ref of this ConnectionValidation.
        :rtype: oci.data_connectivity.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this ConnectionValidation.

        :param parent_ref: The parent_ref of this ConnectionValidation.
        :type: oci.data_connectivity.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this ConnectionValidation.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this ConnectionValidation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConnectionValidation.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this ConnectionValidation.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ConnectionValidation.
        Detailed description for the object.


        :return: The description of this ConnectionValidation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConnectionValidation.
        Detailed description for the object.


        :param description: The description of this ConnectionValidation.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this ConnectionValidation.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this ConnectionValidation.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this ConnectionValidation.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this ConnectionValidation.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this ConnectionValidation.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this ConnectionValidation.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this ConnectionValidation.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this ConnectionValidation.
        :type: int
        """
        self._object_status = object_status

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this ConnectionValidation.

        :return: The registry_metadata of this ConnectionValidation.
        :rtype: oci.data_connectivity.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this ConnectionValidation.

        :param registry_metadata: The registry_metadata of this ConnectionValidation.
        :type: oci.data_connectivity.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    @property
    def connection(self):
        """
        Gets the connection of this ConnectionValidation.

        :return: The connection of this ConnectionValidation.
        :rtype: oci.data_connectivity.models.CreateConnectionDetails
        """
        return self._connection

    @connection.setter
    def connection(self, connection):
        """
        Sets the connection of this ConnectionValidation.

        :param connection: The connection of this ConnectionValidation.
        :type: oci.data_connectivity.models.CreateConnectionDetails
        """
        self._connection = connection

    @property
    def data_asset(self):
        """
        Gets the data_asset of this ConnectionValidation.

        :return: The data_asset of this ConnectionValidation.
        :rtype: oci.data_connectivity.models.CreateDataAssetDetails
        """
        return self._data_asset

    @data_asset.setter
    def data_asset(self, data_asset):
        """
        Sets the data_asset of this ConnectionValidation.

        :param data_asset: The data_asset of this ConnectionValidation.
        :type: oci.data_connectivity.models.CreateDataAssetDetails
        """
        self._data_asset = data_asset

    @property
    def identifier(self):
        """
        Gets the identifier of this ConnectionValidation.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this ConnectionValidation.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this ConnectionValidation.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this ConnectionValidation.
        :type: str
        """
        self._identifier = identifier

    @property
    def metadata(self):
        """
        Gets the metadata of this ConnectionValidation.

        :return: The metadata of this ConnectionValidation.
        :rtype: oci.data_connectivity.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ConnectionValidation.

        :param metadata: The metadata of this ConnectionValidation.
        :type: oci.data_connectivity.models.ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DownloadMaskingPolicyDetails(object):
    """
    Details to download a masking policy.
    """

    #: A constant which can be used with the policy_format property of a DownloadMaskingPolicyDetails.
    #: This constant has a value of "XML"
    POLICY_FORMAT_XML = "XML"

    def __init__(self, **kwargs):
        """
        Initializes a new DownloadMaskingPolicyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_format:
            The value to assign to the policy_format property of this DownloadMaskingPolicyDetails.
            Allowed values for this property are: "XML"
        :type policy_format: str

        """
        self.swagger_types = {
            'policy_format': 'str'
        }

        self.attribute_map = {
            'policy_format': 'policyFormat'
        }

        self._policy_format = None

    @property
    def policy_format(self):
        """
        Gets the policy_format of this DownloadMaskingPolicyDetails.
        The format of the masking policy file.

        Allowed values for this property are: "XML"


        :return: The policy_format of this DownloadMaskingPolicyDetails.
        :rtype: str
        """
        return self._policy_format

    @policy_format.setter
    def policy_format(self, policy_format):
        """
        Sets the policy_format of this DownloadMaskingPolicyDetails.
        The format of the masking policy file.


        :param policy_format: The policy_format of this DownloadMaskingPolicyDetails.
        :type: str
        """
        allowed_values = ["XML"]
        if not value_allowed_none_or_none_sentinel(policy_format, allowed_values):
            raise ValueError(
                "Invalid value for `policy_format`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._policy_format = policy_format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryOpsiDataObjectDataDetails(object):
    """
    Information required to form and execute query on an OPSI data object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryOpsiDataObjectDataDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_object_identifier:
            The value to assign to the data_object_identifier property of this QueryOpsiDataObjectDataDetails.
        :type data_object_identifier: str

        :param query:
            The value to assign to the query property of this QueryOpsiDataObjectDataDetails.
        :type query: oci.opsi.models.DataObjectQuery

        :param resource_filters:
            The value to assign to the resource_filters property of this QueryOpsiDataObjectDataDetails.
        :type resource_filters: oci.opsi.models.ResourceFilters

        """
        self.swagger_types = {
            'data_object_identifier': 'str',
            'query': 'DataObjectQuery',
            'resource_filters': 'ResourceFilters'
        }

        self.attribute_map = {
            'data_object_identifier': 'dataObjectIdentifier',
            'query': 'query',
            'resource_filters': 'resourceFilters'
        }

        self._data_object_identifier = None
        self._query = None
        self._resource_filters = None

    @property
    def data_object_identifier(self):
        """
        Gets the data_object_identifier of this QueryOpsiDataObjectDataDetails.
        Unique OPSI data object identifier.


        :return: The data_object_identifier of this QueryOpsiDataObjectDataDetails.
        :rtype: str
        """
        return self._data_object_identifier

    @data_object_identifier.setter
    def data_object_identifier(self, data_object_identifier):
        """
        Sets the data_object_identifier of this QueryOpsiDataObjectDataDetails.
        Unique OPSI data object identifier.


        :param data_object_identifier: The data_object_identifier of this QueryOpsiDataObjectDataDetails.
        :type: str
        """
        self._data_object_identifier = data_object_identifier

    @property
    def query(self):
        """
        **[Required]** Gets the query of this QueryOpsiDataObjectDataDetails.

        :return: The query of this QueryOpsiDataObjectDataDetails.
        :rtype: oci.opsi.models.DataObjectQuery
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this QueryOpsiDataObjectDataDetails.

        :param query: The query of this QueryOpsiDataObjectDataDetails.
        :type: oci.opsi.models.DataObjectQuery
        """
        self._query = query

    @property
    def resource_filters(self):
        """
        Gets the resource_filters of this QueryOpsiDataObjectDataDetails.

        :return: The resource_filters of this QueryOpsiDataObjectDataDetails.
        :rtype: oci.opsi.models.ResourceFilters
        """
        return self._resource_filters

    @resource_filters.setter
    def resource_filters(self, resource_filters):
        """
        Sets the resource_filters of this QueryOpsiDataObjectDataDetails.

        :param resource_filters: The resource_filters of this QueryOpsiDataObjectDataDetails.
        :type: oci.opsi.models.ResourceFilters
        """
        self._resource_filters = resource_filters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PivotKeys(object):
    """
    The type representing the pivot key and pivot value details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PivotKeys object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param pivot_axis:
            The value to assign to the pivot_axis property of this PivotKeys.
        :type pivot_axis: list[str]

        :param pivot_key_value_map:
            The value to assign to the pivot_key_value_map property of this PivotKeys.
        :type pivot_key_value_map: dict(str, list[str])

        :param key:
            The value to assign to the key property of this PivotKeys.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this PivotKeys.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this PivotKeys.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this PivotKeys.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param object_status:
            The value to assign to the object_status property of this PivotKeys.
        :type object_status: int

        """
        self.swagger_types = {
            'pivot_axis': 'list[str]',
            'pivot_key_value_map': 'dict(str, list[str])',
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'object_status': 'int'
        }

        self.attribute_map = {
            'pivot_axis': 'pivotAxis',
            'pivot_key_value_map': 'pivotKeyValueMap',
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'object_status': 'objectStatus'
        }

        self._pivot_axis = None
        self._pivot_key_value_map = None
        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._object_status = None

    @property
    def pivot_axis(self):
        """
        Gets the pivot_axis of this PivotKeys.
        The pivot axis is the point around which the table will be rotated, and the pivot values will be transposed into columns in the output table.


        :return: The pivot_axis of this PivotKeys.
        :rtype: list[str]
        """
        return self._pivot_axis

    @pivot_axis.setter
    def pivot_axis(self, pivot_axis):
        """
        Sets the pivot_axis of this PivotKeys.
        The pivot axis is the point around which the table will be rotated, and the pivot values will be transposed into columns in the output table.


        :param pivot_axis: The pivot_axis of this PivotKeys.
        :type: list[str]
        """
        self._pivot_axis = pivot_axis

    @property
    def pivot_key_value_map(self):
        """
        Gets the pivot_key_value_map of this PivotKeys.
        Map of alias to pivot key values.


        :return: The pivot_key_value_map of this PivotKeys.
        :rtype: dict(str, list[str])
        """
        return self._pivot_key_value_map

    @pivot_key_value_map.setter
    def pivot_key_value_map(self, pivot_key_value_map):
        """
        Sets the pivot_key_value_map of this PivotKeys.
        Map of alias to pivot key values.


        :param pivot_key_value_map: The pivot_key_value_map of this PivotKeys.
        :type: dict(str, list[str])
        """
        self._pivot_key_value_map = pivot_key_value_map

    @property
    def key(self):
        """
        Gets the key of this PivotKeys.
        The key of the object.


        :return: The key of this PivotKeys.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this PivotKeys.
        The key of the object.


        :param key: The key of this PivotKeys.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this PivotKeys.
        The type of the object.


        :return: The model_type of this PivotKeys.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this PivotKeys.
        The type of the object.


        :param model_type: The model_type of this PivotKeys.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this PivotKeys.
        The model version of an object.


        :return: The model_version of this PivotKeys.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this PivotKeys.
        The model version of an object.


        :param model_version: The model_version of this PivotKeys.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this PivotKeys.

        :return: The parent_ref of this PivotKeys.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this PivotKeys.

        :param parent_ref: The parent_ref of this PivotKeys.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def object_status(self):
        """
        Gets the object_status of this PivotKeys.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this PivotKeys.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this PivotKeys.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this PivotKeys.
        :type: int
        """
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NetworkConnectivityStatus(object):
    """
    The network validation status for a Private Endpoint - Data Asset pair.
    """

    #: A constant which can be used with the network_validation_status_enum property of a NetworkConnectivityStatus.
    #: This constant has a value of "REACHABLE"
    NETWORK_VALIDATION_STATUS_ENUM_REACHABLE = "REACHABLE"

    #: A constant which can be used with the network_validation_status_enum property of a NetworkConnectivityStatus.
    #: This constant has a value of "NOT_REACHABLE"
    NETWORK_VALIDATION_STATUS_ENUM_NOT_REACHABLE = "NOT_REACHABLE"

    #: A constant which can be used with the network_validation_status_enum property of a NetworkConnectivityStatus.
    #: This constant has a value of "ERROR"
    NETWORK_VALIDATION_STATUS_ENUM_ERROR = "ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new NetworkConnectivityStatus object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_asset_key:
            The value to assign to the data_asset_key property of this NetworkConnectivityStatus.
        :type data_asset_key: str

        :param private_end_point_key:
            The value to assign to the private_end_point_key property of this NetworkConnectivityStatus.
        :type private_end_point_key: str

        :param error_message:
            The value to assign to the error_message property of this NetworkConnectivityStatus.
        :type error_message: str

        :param time_last_updated:
            The value to assign to the time_last_updated property of this NetworkConnectivityStatus.
        :type time_last_updated: datetime

        :param network_validation_status_enum:
            The value to assign to the network_validation_status_enum property of this NetworkConnectivityStatus.
            Allowed values for this property are: "REACHABLE", "NOT_REACHABLE", "ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type network_validation_status_enum: str

        """
        self.swagger_types = {
            'data_asset_key': 'str',
            'private_end_point_key': 'str',
            'error_message': 'str',
            'time_last_updated': 'datetime',
            'network_validation_status_enum': 'str'
        }

        self.attribute_map = {
            'data_asset_key': 'dataAssetKey',
            'private_end_point_key': 'privateEndPointKey',
            'error_message': 'errorMessage',
            'time_last_updated': 'timeLastUpdated',
            'network_validation_status_enum': 'networkValidationStatusEnum'
        }

        self._data_asset_key = None
        self._private_end_point_key = None
        self._error_message = None
        self._time_last_updated = None
        self._network_validation_status_enum = None

    @property
    def data_asset_key(self):
        """
        **[Required]** Gets the data_asset_key of this NetworkConnectivityStatus.
        DataAsset key to which the NetworkValidationStatus belongs to.


        :return: The data_asset_key of this NetworkConnectivityStatus.
        :rtype: str
        """
        return self._data_asset_key

    @data_asset_key.setter
    def data_asset_key(self, data_asset_key):
        """
        Sets the data_asset_key of this NetworkConnectivityStatus.
        DataAsset key to which the NetworkValidationStatus belongs to.


        :param data_asset_key: The data_asset_key of this NetworkConnectivityStatus.
        :type: str
        """
        self._data_asset_key = data_asset_key

    @property
    def private_end_point_key(self):
        """
        Gets the private_end_point_key of this NetworkConnectivityStatus.
        PrivateEndpoint key, if any, to which the NetworkValidationStatus belongs to.


        :return: The private_end_point_key of this NetworkConnectivityStatus.
        :rtype: str
        """
        return self._private_end_point_key

    @private_end_point_key.setter
    def private_end_point_key(self, private_end_point_key):
        """
        Sets the private_end_point_key of this NetworkConnectivityStatus.
        PrivateEndpoint key, if any, to which the NetworkValidationStatus belongs to.


        :param private_end_point_key: The private_end_point_key of this NetworkConnectivityStatus.
        :type: str
        """
        self._private_end_point_key = private_end_point_key

    @property
    def error_message(self):
        """
        Gets the error_message of this NetworkConnectivityStatus.
        Exception or error message encountered while testing network reachability for the data asset.


        :return: The error_message of this NetworkConnectivityStatus.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this NetworkConnectivityStatus.
        Exception or error message encountered while testing network reachability for the data asset.


        :param error_message: The error_message of this NetworkConnectivityStatus.
        :type: str
        """
        self._error_message = error_message

    @property
    def time_last_updated(self):
        """
        Gets the time_last_updated of this NetworkConnectivityStatus.
        Instant when the network validation was last done for the given DataAsset-PrivateEndpoint pair..


        :return: The time_last_updated of this NetworkConnectivityStatus.
        :rtype: datetime
        """
        return self._time_last_updated

    @time_last_updated.setter
    def time_last_updated(self, time_last_updated):
        """
        Sets the time_last_updated of this NetworkConnectivityStatus.
        Instant when the network validation was last done for the given DataAsset-PrivateEndpoint pair..


        :param time_last_updated: The time_last_updated of this NetworkConnectivityStatus.
        :type: datetime
        """
        self._time_last_updated = time_last_updated

    @property
    def network_validation_status_enum(self):
        """
        Gets the network_validation_status_enum of this NetworkConnectivityStatus.
        Exception or error message encountered while testing network reachability for the data asset.

        Allowed values for this property are: "REACHABLE", "NOT_REACHABLE", "ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The network_validation_status_enum of this NetworkConnectivityStatus.
        :rtype: str
        """
        return self._network_validation_status_enum

    @network_validation_status_enum.setter
    def network_validation_status_enum(self, network_validation_status_enum):
        """
        Sets the network_validation_status_enum of this NetworkConnectivityStatus.
        Exception or error message encountered while testing network reachability for the data asset.


        :param network_validation_status_enum: The network_validation_status_enum of this NetworkConnectivityStatus.
        :type: str
        """
        allowed_values = ["REACHABLE", "NOT_REACHABLE", "ERROR"]
        if not value_allowed_none_or_none_sentinel(network_validation_status_enum, allowed_values):
            network_validation_status_enum = 'UNKNOWN_ENUM_VALUE'
        self._network_validation_status_enum = network_validation_status_enum

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CalculateAuditVolumeAvailableDetails(object):
    """
    The details for calculating audit data volume on target.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CalculateAuditVolumeAvailableDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param audit_collection_start_time:
            The value to assign to the audit_collection_start_time property of this CalculateAuditVolumeAvailableDetails.
        :type audit_collection_start_time: datetime

        :param trail_locations:
            The value to assign to the trail_locations property of this CalculateAuditVolumeAvailableDetails.
        :type trail_locations: list[str]

        """
        self.swagger_types = {
            'audit_collection_start_time': 'datetime',
            'trail_locations': 'list[str]'
        }

        self.attribute_map = {
            'audit_collection_start_time': 'auditCollectionStartTime',
            'trail_locations': 'trailLocations'
        }

        self._audit_collection_start_time = None
        self._trail_locations = None

    @property
    def audit_collection_start_time(self):
        """
        Gets the audit_collection_start_time of this CalculateAuditVolumeAvailableDetails.
        The date from which the audit trail must start collecting data in UTC, in the format defined by RFC3339. If not specified, this will default to the date based on the retention period.


        :return: The audit_collection_start_time of this CalculateAuditVolumeAvailableDetails.
        :rtype: datetime
        """
        return self._audit_collection_start_time

    @audit_collection_start_time.setter
    def audit_collection_start_time(self, audit_collection_start_time):
        """
        Sets the audit_collection_start_time of this CalculateAuditVolumeAvailableDetails.
        The date from which the audit trail must start collecting data in UTC, in the format defined by RFC3339. If not specified, this will default to the date based on the retention period.


        :param audit_collection_start_time: The audit_collection_start_time of this CalculateAuditVolumeAvailableDetails.
        :type: datetime
        """
        self._audit_collection_start_time = audit_collection_start_time

    @property
    def trail_locations(self):
        """
        **[Required]** Gets the trail_locations of this CalculateAuditVolumeAvailableDetails.
        The trail locations for which the audit data volume has to be calculated.


        :return: The trail_locations of this CalculateAuditVolumeAvailableDetails.
        :rtype: list[str]
        """
        return self._trail_locations

    @trail_locations.setter
    def trail_locations(self, trail_locations):
        """
        Sets the trail_locations of this CalculateAuditVolumeAvailableDetails.
        The trail locations for which the audit data volume has to be calculated.


        :param trail_locations: The trail_locations of this CalculateAuditVolumeAvailableDetails.
        :type: list[str]
        """
        self._trail_locations = trail_locations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Country(object):
    """
    Country details model
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Country object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param country_id:
            The value to assign to the country_id property of this Country.
        :type country_id: float

        :param country_code:
            The value to assign to the country_code property of this Country.
        :type country_code: str

        :param country_name:
            The value to assign to the country_name property of this Country.
        :type country_name: str

        :param language_id:
            The value to assign to the language_id property of this Country.
        :type language_id: float

        :param ascii3_country_code:
            The value to assign to the ascii3_country_code property of this Country.
        :type ascii3_country_code: str

        """
        self.swagger_types = {
            'country_id': 'float',
            'country_code': 'str',
            'country_name': 'str',
            'language_id': 'float',
            'ascii3_country_code': 'str'
        }

        self.attribute_map = {
            'country_id': 'countryId',
            'country_code': 'countryCode',
            'country_name': 'countryName',
            'language_id': 'languageId',
            'ascii3_country_code': 'ascii3CountryCode'
        }

        self._country_id = None
        self._country_code = None
        self._country_name = None
        self._language_id = None
        self._ascii3_country_code = None

    @property
    def country_id(self):
        """
        Gets the country_id of this Country.
        Indentifier of the country. This is a DB side unique id which was generated when the entity was created in the table


        :return: The country_id of this Country.
        :rtype: float
        """
        return self._country_id

    @country_id.setter
    def country_id(self, country_id):
        """
        Sets the country_id of this Country.
        Indentifier of the country. This is a DB side unique id which was generated when the entity was created in the table


        :param country_id: The country_id of this Country.
        :type: float
        """
        self._country_id = country_id

    @property
    def country_code(self):
        """
        Gets the country_code of this Country.
        Country code in ISO-3166-1 2-letter format


        :return: The country_code of this Country.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this Country.
        Country code in ISO-3166-1 2-letter format


        :param country_code: The country_code of this Country.
        :type: str
        """
        self._country_code = country_code

    @property
    def country_name(self):
        """
        Gets the country_name of this Country.
        Name of the country


        :return: The country_name of this Country.
        :rtype: str
        """
        return self._country_name

    @country_name.setter
    def country_name(self, country_name):
        """
        Sets the country_name of this Country.
        Name of the country


        :param country_name: The country_name of this Country.
        :type: str
        """
        self._country_name = country_name

    @property
    def language_id(self):
        """
        Gets the language_id of this Country.
        Language identifier


        :return: The language_id of this Country.
        :rtype: float
        """
        return self._language_id

    @language_id.setter
    def language_id(self, language_id):
        """
        Sets the language_id of this Country.
        Language identifier


        :param language_id: The language_id of this Country.
        :type: float
        """
        self._language_id = language_id

    @property
    def ascii3_country_code(self):
        """
        Gets the ascii3_country_code of this Country.
        Country code in ISO-3166-1 3-letter format


        :return: The ascii3_country_code of this Country.
        :rtype: str
        """
        return self._ascii3_country_code

    @ascii3_country_code.setter
    def ascii3_country_code(self, ascii3_country_code):
        """
        Sets the ascii3_country_code of this Country.
        Country code in ISO-3166-1 3-letter format


        :param ascii3_country_code: The ascii3_country_code of this Country.
        :type: str
        """
        self._ascii3_country_code = ascii3_country_code

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .annotation import Annotation
from .annotation_aggregation_dimensions import AnnotationAggregationDimensions
from .annotation_analytics_aggregation import AnnotationAnalyticsAggregation
from .annotation_analytics_aggregation_collection import AnnotationAnalyticsAggregationCollection
from .annotation_collection import AnnotationCollection
from .annotation_summary import AnnotationSummary
from .bounding_polygon import BoundingPolygon
from .create_annotation_details import CreateAnnotationDetails
from .create_object_storage_source_details import CreateObjectStorageSourceDetails
from .create_record_details import CreateRecordDetails
from .create_source_details import CreateSourceDetails
from .dataset import Dataset
from .dataset_format_details import DatasetFormatDetails
from .dataset_source_details import DatasetSourceDetails
from .document_dataset_format_details import DocumentDatasetFormatDetails
from .document_metadata import DocumentMetadata
from .entity import Entity
from .generic_entity import GenericEntity
from .image_dataset_format_details import ImageDatasetFormatDetails
from .image_metadata import ImageMetadata
from .image_object_selection_entity import ImageObjectSelectionEntity
from .initial_record_generation_configuration import InitialRecordGenerationConfiguration
from .label import Label
from .label_name import LabelName
from .label_set import LabelSet
from .normalized_vertex import NormalizedVertex
from .object_storage_dataset_source_details import ObjectStorageDatasetSourceDetails
from .object_storage_source_details import ObjectStorageSourceDetails
from .record import Record
from .record_aggregation_dimensions import RecordAggregationDimensions
from .record_analytics_aggregation import RecordAnalyticsAggregation
from .record_analytics_aggregation_collection import RecordAnalyticsAggregationCollection
from .record_collection import RecordCollection
from .record_metadata import RecordMetadata
from .record_summary import RecordSummary
from .source_details import SourceDetails
from .text_dataset_format_details import TextDatasetFormatDetails
from .text_metadata import TextMetadata
from .text_selection_entity import TextSelectionEntity
from .text_span import TextSpan
from .update_annotation_details import UpdateAnnotationDetails
from .update_record_details import UpdateRecordDetails

# Maps type names to classes for data_labeling_service_dataplane services.
data_labeling_service_dataplane_type_mapping = {
    "Annotation": Annotation,
    "AnnotationAggregationDimensions": AnnotationAggregationDimensions,
    "AnnotationAnalyticsAggregation": AnnotationAnalyticsAggregation,
    "AnnotationAnalyticsAggregationCollection": AnnotationAnalyticsAggregationCollection,
    "AnnotationCollection": AnnotationCollection,
    "AnnotationSummary": AnnotationSummary,
    "BoundingPolygon": BoundingPolygon,
    "CreateAnnotationDetails": CreateAnnotationDetails,
    "CreateObjectStorageSourceDetails": CreateObjectStorageSourceDetails,
    "CreateRecordDetails": CreateRecordDetails,
    "CreateSourceDetails": CreateSourceDetails,
    "Dataset": Dataset,
    "DatasetFormatDetails": DatasetFormatDetails,
    "DatasetSourceDetails": DatasetSourceDetails,
    "DocumentDatasetFormatDetails": DocumentDatasetFormatDetails,
    "DocumentMetadata": DocumentMetadata,
    "Entity": Entity,
    "GenericEntity": GenericEntity,
    "ImageDatasetFormatDetails": ImageDatasetFormatDetails,
    "ImageMetadata": ImageMetadata,
    "ImageObjectSelectionEntity": ImageObjectSelectionEntity,
    "InitialRecordGenerationConfiguration": InitialRecordGenerationConfiguration,
    "Label": Label,
    "LabelName": LabelName,
    "LabelSet": LabelSet,
    "NormalizedVertex": NormalizedVertex,
    "ObjectStorageDatasetSourceDetails": ObjectStorageDatasetSourceDetails,
    "ObjectStorageSourceDetails": ObjectStorageSourceDetails,
    "Record": Record,
    "RecordAggregationDimensions": RecordAggregationDimensions,
    "RecordAnalyticsAggregation": RecordAnalyticsAggregation,
    "RecordAnalyticsAggregationCollection": RecordAnalyticsAggregationCollection,
    "RecordCollection": RecordCollection,
    "RecordMetadata": RecordMetadata,
    "RecordSummary": RecordSummary,
    "SourceDetails": SourceDetails,
    "TextDatasetFormatDetails": TextDatasetFormatDetails,
    "TextMetadata": TextMetadata,
    "TextSelectionEntity": TextSelectionEntity,
    "TextSpan": TextSpan,
    "UpdateAnnotationDetails": UpdateAnnotationDetails,
    "UpdateRecordDetails": UpdateRecordDetails
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OdaInstance(object):
    """
    Description of `OdaServiceInstance` object.
    """

    #: A constant which can be used with the shape_name property of a OdaInstance.
    #: This constant has a value of "DEVELOPMENT"
    SHAPE_NAME_DEVELOPMENT = "DEVELOPMENT"

    #: A constant which can be used with the shape_name property of a OdaInstance.
    #: This constant has a value of "PRODUCTION"
    SHAPE_NAME_PRODUCTION = "PRODUCTION"

    #: A constant which can be used with the lifecycle_state property of a OdaInstance.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a OdaInstance.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a OdaInstance.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OdaInstance.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OdaInstance.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a OdaInstance.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a OdaInstance.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "CREATING"
    LIFECYCLE_SUB_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "STARTING"
    LIFECYCLE_SUB_STATE_STARTING = "STARTING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "STOPPING"
    LIFECYCLE_SUB_STATE_STOPPING = "STOPPING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "CHANGING_COMPARTMENT"
    LIFECYCLE_SUB_STATE_CHANGING_COMPARTMENT = "CHANGING_COMPARTMENT"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "ACTIVATING_CUSTOMER_ENCRYPTION_KEY"
    LIFECYCLE_SUB_STATE_ACTIVATING_CUSTOMER_ENCRYPTION_KEY = "ACTIVATING_CUSTOMER_ENCRYPTION_KEY"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "UPDATING_CUSTOMER_ENCRYPTION_KEY"
    LIFECYCLE_SUB_STATE_UPDATING_CUSTOMER_ENCRYPTION_KEY = "UPDATING_CUSTOMER_ENCRYPTION_KEY"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "DEACTIVATING_CUSTOMER_ENCRYPTION_KEY"
    LIFECYCLE_SUB_STATE_DEACTIVATING_CUSTOMER_ENCRYPTION_KEY = "DEACTIVATING_CUSTOMER_ENCRYPTION_KEY"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "DELETING"
    LIFECYCLE_SUB_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "DELETE_PENDING"
    LIFECYCLE_SUB_STATE_DELETE_PENDING = "DELETE_PENDING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "RECOVERING"
    LIFECYCLE_SUB_STATE_RECOVERING = "RECOVERING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_SUB_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "PURGING"
    LIFECYCLE_SUB_STATE_PURGING = "PURGING"

    #: A constant which can be used with the lifecycle_sub_state property of a OdaInstance.
    #: This constant has a value of "QUEUED"
    LIFECYCLE_SUB_STATE_QUEUED = "QUEUED"

    def __init__(self, **kwargs):
        """
        Initializes a new OdaInstance object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OdaInstance.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this OdaInstance.
        :type display_name: str

        :param description:
            The value to assign to the description property of this OdaInstance.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this OdaInstance.
        :type compartment_id: str

        :param shape_name:
            The value to assign to the shape_name property of this OdaInstance.
            Allowed values for this property are: "DEVELOPMENT", "PRODUCTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type shape_name: str

        :param web_app_url:
            The value to assign to the web_app_url property of this OdaInstance.
        :type web_app_url: str

        :param connector_url:
            The value to assign to the connector_url property of this OdaInstance.
        :type connector_url: str

        :param time_created:
            The value to assign to the time_created property of this OdaInstance.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this OdaInstance.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OdaInstance.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_sub_state:
            The value to assign to the lifecycle_sub_state property of this OdaInstance.
            Allowed values for this property are: "CREATING", "STARTING", "STOPPING", "CHANGING_COMPARTMENT", "ACTIVATING_CUSTOMER_ENCRYPTION_KEY", "UPDATING_CUSTOMER_ENCRYPTION_KEY", "DEACTIVATING_CUSTOMER_ENCRYPTION_KEY", "DELETING", "DELETE_PENDING", "RECOVERING", "UPDATING", "PURGING", "QUEUED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_sub_state: str

        :param state_message:
            The value to assign to the state_message property of this OdaInstance.
        :type state_message: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this OdaInstance.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this OdaInstance.
        :type defined_tags: dict(str, dict(str, object))

        :param is_role_based_access:
            The value to assign to the is_role_based_access property of this OdaInstance.
        :type is_role_based_access: bool

        :param identity_domain:
            The value to assign to the identity_domain property of this OdaInstance.
        :type identity_domain: str

        :param identity_app_guid:
            The value to assign to the identity_app_guid property of this OdaInstance.
        :type identity_app_guid: str

        :param identity_app_console_url:
            The value to assign to the identity_app_console_url property of this OdaInstance.
        :type identity_app_console_url: str

        :param imported_package_names:
            The value to assign to the imported_package_names property of this OdaInstance.
        :type imported_package_names: list[str]

        :param imported_package_ids:
            The value to assign to the imported_package_ids property of this OdaInstance.
        :type imported_package_ids: list[str]

        :param attachment_types:
            The value to assign to the attachment_types property of this OdaInstance.
        :type attachment_types: list[str]

        :param attachment_ids:
            The value to assign to the attachment_ids property of this OdaInstance.
        :type attachment_ids: list[str]

        :param restricted_operations:
            The value to assign to the restricted_operations property of this OdaInstance.
        :type restricted_operations: list[oci.oda.models.RestrictedOperation]

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'shape_name': 'str',
            'web_app_url': 'str',
            'connector_url': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_sub_state': 'str',
            'state_message': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'is_role_based_access': 'bool',
            'identity_domain': 'str',
            'identity_app_guid': 'str',
            'identity_app_console_url': 'str',
            'imported_package_names': 'list[str]',
            'imported_package_ids': 'list[str]',
            'attachment_types': 'list[str]',
            'attachment_ids': 'list[str]',
            'restricted_operations': 'list[RestrictedOperation]'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'shape_name': 'shapeName',
            'web_app_url': 'webAppUrl',
            'connector_url': 'connectorUrl',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_sub_state': 'lifecycleSubState',
            'state_message': 'stateMessage',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'is_role_based_access': 'isRoleBasedAccess',
            'identity_domain': 'identityDomain',
            'identity_app_guid': 'identityAppGuid',
            'identity_app_console_url': 'identityAppConsoleUrl',
            'imported_package_names': 'importedPackageNames',
            'imported_package_ids': 'importedPackageIds',
            'attachment_types': 'attachmentTypes',
            'attachment_ids': 'attachmentIds',
            'restricted_operations': 'restrictedOperations'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._shape_name = None
        self._web_app_url = None
        self._connector_url = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_sub_state = None
        self._state_message = None
        self._freeform_tags = None
        self._defined_tags = None
        self._is_role_based_access = None
        self._identity_domain = None
        self._identity_app_guid = None
        self._identity_app_console_url = None
        self._imported_package_names = None
        self._imported_package_ids = None
        self._attachment_types = None
        self._attachment_ids = None
        self._restricted_operations = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this OdaInstance.
        Unique immutable identifier that was assigned when the instance was created.


        :return: The id of this OdaInstance.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OdaInstance.
        Unique immutable identifier that was assigned when the instance was created.


        :param id: The id of this OdaInstance.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this OdaInstance.
        User-defined name for the Digital Assistant instance. Avoid entering confidential information.
        You can change this value.


        :return: The display_name of this OdaInstance.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this OdaInstance.
        User-defined name for the Digital Assistant instance. Avoid entering confidential information.
        You can change this value.


        :param display_name: The display_name of this OdaInstance.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this OdaInstance.
        Description of the Digital Assistant instance.


        :return: The description of this OdaInstance.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OdaInstance.
        Description of the Digital Assistant instance.


        :param description: The description of this OdaInstance.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this OdaInstance.
        Identifier of the compartment that the instance belongs to.


        :return: The compartment_id of this OdaInstance.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this OdaInstance.
        Identifier of the compartment that the instance belongs to.


        :param compartment_id: The compartment_id of this OdaInstance.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def shape_name(self):
        """
        **[Required]** Gets the shape_name of this OdaInstance.
        Shape or size of the instance.

        Allowed values for this property are: "DEVELOPMENT", "PRODUCTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The shape_name of this OdaInstance.
        :rtype: str
        """
        return self._shape_name

    @shape_name.setter
    def shape_name(self, shape_name):
        """
        Sets the shape_name of this OdaInstance.
        Shape or size of the instance.


        :param shape_name: The shape_name of this OdaInstance.
        :type: str
        """
        allowed_values = ["DEVELOPMENT", "PRODUCTION"]
        if not value_allowed_none_or_none_sentinel(shape_name, allowed_values):
            shape_name = 'UNKNOWN_ENUM_VALUE'
        self._shape_name = shape_name

    @property
    def web_app_url(self):
        """
        Gets the web_app_url of this OdaInstance.
        URL for the Digital Assistant web application that's associated with the instance.


        :return: The web_app_url of this OdaInstance.
        :rtype: str
        """
        return self._web_app_url

    @web_app_url.setter
    def web_app_url(self, web_app_url):
        """
        Sets the web_app_url of this OdaInstance.
        URL for the Digital Assistant web application that's associated with the instance.


        :param web_app_url: The web_app_url of this OdaInstance.
        :type: str
        """
        self._web_app_url = web_app_url

    @property
    def connector_url(self):
        """
        Gets the connector_url of this OdaInstance.
        URL for the connector's endpoint.


        :return: The connector_url of this OdaInstance.
        :rtype: str
        """
        return self._connector_url

    @connector_url.setter
    def connector_url(self, connector_url):
        """
        Sets the connector_url of this OdaInstance.
        URL for the connector's endpoint.


        :param connector_url: The connector_url of this OdaInstance.
        :type: str
        """
        self._connector_url = connector_url

    @property
    def time_created(self):
        """
        Gets the time_created of this OdaInstance.
        When the Digital Assistant instance was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this OdaInstance.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this OdaInstance.
        When the Digital Assistant instance was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this OdaInstance.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this OdaInstance.
        When the Digital Assistance instance was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this OdaInstance.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this OdaInstance.
        When the Digital Assistance instance was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this OdaInstance.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this OdaInstance.
        The current state of the Digital Assistant instance.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this OdaInstance.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this OdaInstance.
        The current state of the Digital Assistant instance.


        :param lifecycle_state: The lifecycle_state of this OdaInstance.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_sub_state(self):
        """
        Gets the lifecycle_sub_state of this OdaInstance.
        The current sub-state of the Digital Assistant instance.

        Allowed values for this property are: "CREATING", "STARTING", "STOPPING", "CHANGING_COMPARTMENT", "ACTIVATING_CUSTOMER_ENCRYPTION_KEY", "UPDATING_CUSTOMER_ENCRYPTION_KEY", "DEACTIVATING_CUSTOMER_ENCRYPTION_KEY", "DELETING", "DELETE_PENDING", "RECOVERING", "UPDATING", "PURGING", "QUEUED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_sub_state of this OdaInstance.
        :rtype: str
        """
        return self._lifecycle_sub_state

    @lifecycle_sub_state.setter
    def lifecycle_sub_state(self, lifecycle_sub_state):
        """
        Sets the lifecycle_sub_state of this OdaInstance.
        The current sub-state of the Digital Assistant instance.


        :param lifecycle_sub_state: The lifecycle_sub_state of this OdaInstance.
        :type: str
        """
        allowed_values = ["CREATING", "STARTING", "STOPPING", "CHANGING_COMPARTMENT", "ACTIVATING_CUSTOMER_ENCRYPTION_KEY", "UPDATING_CUSTOMER_ENCRYPTION_KEY", "DEACTIVATING_CUSTOMER_ENCRYPTION_KEY", "DELETING", "DELETE_PENDING", "RECOVERING", "UPDATING", "PURGING", "QUEUED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_sub_state, allowed_values):
            lifecycle_sub_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_sub_state = lifecycle_sub_state

    @property
    def state_message(self):
        """
        Gets the state_message of this OdaInstance.
        A message that describes the current state in more detail.
        For example, actionable information about an instance that's in the `FAILED` state.


        :return: The state_message of this OdaInstance.
        :rtype: str
        """
        return self._state_message

    @state_message.setter
    def state_message(self, state_message):
        """
        Sets the state_message of this OdaInstance.
        A message that describes the current state in more detail.
        For example, actionable information about an instance that's in the `FAILED` state.


        :param state_message: The state_message of this OdaInstance.
        :type: str
        """
        self._state_message = state_message

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this OdaInstance.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this OdaInstance.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this OdaInstance.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this OdaInstance.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this OdaInstance.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this OdaInstance.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this OdaInstance.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this OdaInstance.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def is_role_based_access(self):
        """
        Gets the is_role_based_access of this OdaInstance.
        Should this Digital Assistant instance use role-based authorization via an identity domain (true) or use the default policy-based authorization via IAM policies (false)


        :return: The is_role_based_access of this OdaInstance.
        :rtype: bool
        """
        return self._is_role_based_access

    @is_role_based_access.setter
    def is_role_based_access(self, is_role_based_access):
        """
        Sets the is_role_based_access of this OdaInstance.
        Should this Digital Assistant instance use role-based authorization via an identity domain (true) or use the default policy-based authorization via IAM policies (false)


        :param is_role_based_access: The is_role_based_access of this OdaInstance.
        :type: bool
        """
        self._is_role_based_access = is_role_based_access

    @property
    def identity_domain(self):
        """
        Gets the identity_domain of this OdaInstance.
        If isRoleBasedAccess is set to true, this property specifies the identity domain that is to be used to implement this type of authorzation. Digital Assistant will create an Identity Application instance and Application Roles within this identity domain. The caller may then perform and user roll mappings they like to grant access to users within the identity domain.


        :return: The identity_domain of this OdaInstance.
        :rtype: str
        """
        return self._identity_domain

    @identity_domain.setter
    def identity_domain(self, identity_domain):
        """
        Sets the identity_domain of this OdaInstance.
        If isRoleBasedAccess is set to true, this property specifies the identity domain that is to be used to implement this type of authorzation. Digital Assistant will create an Identity Application instance and Application Roles within this identity domain. The caller may then perform and user roll mappings they like to grant access to users within the identity domain.


        :param identity_domain: The identity_domain of this OdaInstance.
        :type: str
        """
        self._identity_domain = identity_domain

    @property
    def identity_app_guid(self):
        """
        Gets the identity_app_guid of this OdaInstance.
        If isRoleBasedAccess is set to true, this property specifies the GUID of the Identity Application instance Digital Assistant has created inside the user-specified identity domain. This identity application instance may be used to host user roll mappings to grant access to this Digital Assistant instance for users within the identity domain.


        :return: The identity_app_guid of this OdaInstance.
        :rtype: str
        """
        return self._identity_app_guid

    @identity_app_guid.setter
    def identity_app_guid(self, identity_app_guid):
        """
        Sets the identity_app_guid of this OdaInstance.
        If isRoleBasedAccess is set to true, this property specifies the GUID of the Identity Application instance Digital Assistant has created inside the user-specified identity domain. This identity application instance may be used to host user roll mappings to grant access to this Digital Assistant instance for users within the identity domain.


        :param identity_app_guid: The identity_app_guid of this OdaInstance.
        :type: str
        """
        self._identity_app_guid = identity_app_guid

    @property
    def identity_app_console_url(self):
        """
        Gets the identity_app_console_url of this OdaInstance.
        If isRoleBasedAccess is set to true, this property specifies the URL for the administration console used to manage the Identity Application instance Digital Assistant has created inside the user-specified identity domain.


        :return: The identity_app_console_url of this OdaInstance.
        :rtype: str
        """
        return self._identity_app_console_url

    @identity_app_console_url.setter
    def identity_app_console_url(self, identity_app_console_url):
        """
        Sets the identity_app_console_url of this OdaInstance.
        If isRoleBasedAccess is set to true, this property specifies the URL for the administration console used to manage the Identity Application instance Digital Assistant has created inside the user-specified identity domain.


        :param identity_app_console_url: The identity_app_console_url of this OdaInstance.
        :type: str
        """
        self._identity_app_console_url = identity_app_console_url

    @property
    def imported_package_names(self):
        """
        Gets the imported_package_names of this OdaInstance.
        A list of package names imported into this instance (if any). Use importedPackageIds field to get the details of the imported packages.


        :return: The imported_package_names of this OdaInstance.
        :rtype: list[str]
        """
        return self._imported_package_names

    @imported_package_names.setter
    def imported_package_names(self, imported_package_names):
        """
        Sets the imported_package_names of this OdaInstance.
        A list of package names imported into this instance (if any). Use importedPackageIds field to get the details of the imported packages.


        :param imported_package_names: The imported_package_names of this OdaInstance.
        :type: list[str]
        """
        self._imported_package_names = imported_package_names

    @property
    def imported_package_ids(self):
        """
        Gets the imported_package_ids of this OdaInstance.
        A list of package ids imported into this instance (if any). Use GetImportedPackage to get the details of the imported packages.


        :return: The imported_package_ids of this OdaInstance.
        :rtype: list[str]
        """
        return self._imported_package_ids

    @imported_package_ids.setter
    def imported_package_ids(self, imported_package_ids):
        """
        Sets the imported_package_ids of this OdaInstance.
        A list of package ids imported into this instance (if any). Use GetImportedPackage to get the details of the imported packages.


        :param imported_package_ids: The imported_package_ids of this OdaInstance.
        :type: list[str]
        """
        self._imported_package_ids = imported_package_ids

    @property
    def attachment_types(self):
        """
        Gets the attachment_types of this OdaInstance.
        A list of attachment types for this instance (if any). Use attachmentIds to get the details of the attachments.


        :return: The attachment_types of this OdaInstance.
        :rtype: list[str]
        """
        return self._attachment_types

    @attachment_types.setter
    def attachment_types(self, attachment_types):
        """
        Sets the attachment_types of this OdaInstance.
        A list of attachment types for this instance (if any). Use attachmentIds to get the details of the attachments.


        :param attachment_types: The attachment_types of this OdaInstance.
        :type: list[str]
        """
        self._attachment_types = attachment_types

    @property
    def attachment_ids(self):
        """
        Gets the attachment_ids of this OdaInstance.
        A list of attachment identifiers for this instance (if any). Use GetOdaInstanceAttachment to get the details of the attachments.


        :return: The attachment_ids of this OdaInstance.
        :rtype: list[str]
        """
        return self._attachment_ids

    @attachment_ids.setter
    def attachment_ids(self, attachment_ids):
        """
        Sets the attachment_ids of this OdaInstance.
        A list of attachment identifiers for this instance (if any). Use GetOdaInstanceAttachment to get the details of the attachments.


        :param attachment_ids: The attachment_ids of this OdaInstance.
        :type: list[str]
        """
        self._attachment_ids = attachment_ids

    @property
    def restricted_operations(self):
        """
        Gets the restricted_operations of this OdaInstance.
        A list of restricted operations (across all attachments) for this instance (if any). Use GetOdaInstanceAttachment to get the details of the attachments.


        :return: The restricted_operations of this OdaInstance.
        :rtype: list[oci.oda.models.RestrictedOperation]
        """
        return self._restricted_operations

    @restricted_operations.setter
    def restricted_operations(self, restricted_operations):
        """
        Sets the restricted_operations of this OdaInstance.
        A list of restricted operations (across all attachments) for this instance (if any). Use GetOdaInstanceAttachment to get the details of the attachments.


        :param restricted_operations: The restricted_operations of this OdaInstance.
        :type: list[oci.oda.models.RestrictedOperation]
        """
        self._restricted_operations = restricted_operations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RequestAccessControl(object):
    """
    Module that allows inspection of HTTP request properties and to return a defined HTTP response.
    In this module, rules with the name 'Default Action' are not allowed, since this name is reserved for default action logs.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RequestAccessControl object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param default_action_name:
            The value to assign to the default_action_name property of this RequestAccessControl.
        :type default_action_name: str

        :param rules:
            The value to assign to the rules property of this RequestAccessControl.
        :type rules: list[oci.waf.models.AccessControlRule]

        """
        self.swagger_types = {
            'default_action_name': 'str',
            'rules': 'list[AccessControlRule]'
        }

        self.attribute_map = {
            'default_action_name': 'defaultActionName',
            'rules': 'rules'
        }

        self._default_action_name = None
        self._rules = None

    @property
    def default_action_name(self):
        """
        **[Required]** Gets the default_action_name of this RequestAccessControl.
        References an default Action to take if no AccessControlRule was matched. Allowed action types:

        * **ALLOW** continues execution of other modules and their rules.

        * **RETURN_HTTP_RESPONSE** terminates further execution of modules and rules and returns defined HTTP response.


        :return: The default_action_name of this RequestAccessControl.
        :rtype: str
        """
        return self._default_action_name

    @default_action_name.setter
    def default_action_name(self, default_action_name):
        """
        Sets the default_action_name of this RequestAccessControl.
        References an default Action to take if no AccessControlRule was matched. Allowed action types:

        * **ALLOW** continues execution of other modules and their rules.

        * **RETURN_HTTP_RESPONSE** terminates further execution of modules and rules and returns defined HTTP response.


        :param default_action_name: The default_action_name of this RequestAccessControl.
        :type: str
        """
        self._default_action_name = default_action_name

    @property
    def rules(self):
        """
        Gets the rules of this RequestAccessControl.
        Ordered list of AccessControlRules. Rules are executed in order of appearance in this array.


        :return: The rules of this RequestAccessControl.
        :rtype: list[oci.waf.models.AccessControlRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this RequestAccessControl.
        Ordered list of AccessControlRules. Rules are executed in order of appearance in this array.


        :param rules: The rules of this RequestAccessControl.
        :type: list[oci.waf.models.AccessControlRule]
        """
        self._rules = rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .instance_agent_command_execution_output_content import InstanceAgentCommandExecutionOutputContent
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails(InstanceAgentCommandExecutionOutputContent):
    """
    The execution output from a command when saved to an Object Storage URL.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.compute_instance_agent.models.InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.output_type` attribute
        of this class is ``OBJECT_STORAGE_URI`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param output_type:
            The value to assign to the output_type property of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
            Allowed values for this property are: "TEXT", "OBJECT_STORAGE_URI", "OBJECT_STORAGE_TUPLE"
        :type output_type: str

        :param exit_code:
            The value to assign to the exit_code property of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
        :type exit_code: int

        :param message:
            The value to assign to the message property of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
        :type message: str

        :param output_uri:
            The value to assign to the output_uri property of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
        :type output_uri: str

        """
        self.swagger_types = {
            'output_type': 'str',
            'exit_code': 'int',
            'message': 'str',
            'output_uri': 'str'
        }

        self.attribute_map = {
            'output_type': 'outputType',
            'exit_code': 'exitCode',
            'message': 'message',
            'output_uri': 'outputUri'
        }

        self._output_type = None
        self._exit_code = None
        self._message = None
        self._output_uri = None
        self._output_type = 'OBJECT_STORAGE_URI'

    @property
    def output_uri(self):
        """
        **[Required]** Gets the output_uri of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
        The Object Storage URL or pre-authenticated request (PAR) for the command output.


        :return: The output_uri of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
        :rtype: str
        """
        return self._output_uri

    @output_uri.setter
    def output_uri(self, output_uri):
        """
        Sets the output_uri of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
        The Object Storage URL or pre-authenticated request (PAR) for the command output.


        :param output_uri: The output_uri of this InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails.
        :type: str
        """
        self._output_uri = output_uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
